##  Drill-Down
The drill-down option in the report settings allows you to drill down the base fact sheet to visualize dependencies and relations. It effectively adds an additional dimension to your matrix report, giving you more context and allowing you to dive deeper into the report.
For example, you can drill down an application matrix report by IT component to see the underlying IT components of an application with an unaddressed end-of-life risk. Or drill down by business context to visualize related process dependencies.
To drill down, follow these steps:
  1. Click on Settings.
  2. From the Drill-Down drop-down menu, select the fact sheet type or relation.
  3. Optionally, under the Labels section, use the Drill-Down drop-down menu to choose the display label for the drill-down items.
  4. Click Apply.


![](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loiocb73b083a11d49219e9882eb140828de_LowRes.gif)
Drill-Down Settings
**Note**
Currently, the color-coding based on the applied view only applies to the base fact sheet in the report and not to the related fact sheets shown in the drill-down.
